@@ -107,7 +107,7 @@ void PrintFlowTable(printer_t print_record, uint32_t limitflows, int tag, int Gu
 
 void PrintFlowStat(char *record_header, printer_t print_record, int topN, int tag, int quiet, int cvs_output, extension_map_list_t *extension_map_list);
 
-void PrintElementStat(stat_record_t	*sum_stat, char *record_header, printer_t print_record, int topN, int tag, int quiet, int pipe_output, int cvs_output);
+void PrintElementStat(stat_record_t	*sum_stat, uint32_t limitflows, char *record_header, printer_t print_record, int topN, int tag, int quiet, int pipe_output, int cvs_output);
 
 int ParseListOrder(char *s, int multiple_orders );
 
